/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_yo_BJ extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "003", "\u00c0r\u00edw\u00e1 Am\u025b\u0301r\u00edk\u00e0" },
            { "005", "G\u00fa\u00fash\u00f9 Am\u025b\u0301r\u00edk\u00e0" },
            { "011", "\u00ccw\u0254\u0300 oor\u00f9n Af\u00edr\u00edk\u00e0" },
            { "013", "\u00c0\u00e0rin Gb\u00f9gb\u00f9n \u00c0m\u025b\u0301r\u00edk\u00e0" },
            { "019", "Am\u025b\u0301r\u00edk\u00e0" },
            { "021", "Ap\u00e1\u00e0r\u00edw\u00e1 Am\u025b\u0301r\u00edk\u00e0" },
            { "030", "\u00ccl\u00e0 \u00d2\u00f2r\u00f9n Esh\u00ed\u00e0" },
            { "034", "G\u00fa\u00fash\u00f9 Esh\u00ed\u00e0" },
            { "035", "G\u00fa\u00fash\u00f9 \u00ecl\u00e0 \u00f2\u00f2r\u00f9n \u00c9sh\u00ed\u00e0" },
            { "039", "G\u00fa\u00fash\u00f9 Y\u00far\u00f3\u00f2p\u00f9" },
            { "053", "\u0186shir\u00e9lash\u00ed\u00e0" },
            { "054", "M\u025blan\u00e9sh\u00ed\u00e0" },
            { "057", "Agb\u00e8gb\u00e8 Maikiron\u00e9sh\u00ed\u00e0" },
            { "061", "Polinesh\u00ed\u00e0" },
            { "143", "\u00c0\u00e0rin Gb\u00f9ngb\u00f9n \u00c9sh\u00ed\u00e0" },
            { "145", "\u00ccw\u0254\u0300 \u00d2\u00f2r\u00f9n Esh\u00ed\u00e0" },
            { "155", "\u00ccw\u0254\u0300 \u00d2\u00f2r\u00f9n Y\u00far\u00f3p\u00f9" },
            { "419", "L\u00e1t\u00edn Am\u025b\u0301r\u00edk\u00e0" },
            { "AD", "Or\u00edl\u025b\u0301\u00e8de \u00c0\u00e0nd\u00f3r\u00e0" },
            { "AE", "Or\u00edl\u025b\u0301\u00e8de \u0190mirate ti Aw\u0254n Arabu" },
            { "AF", "Or\u00edl\u025b\u0301\u00e8de \u00c0f\u00f9g\u00e0n\u00edst\u00e1n\u00ec" },
            { "AG", "Or\u00edl\u025b\u0301\u00e8de \u00c0\u00e0nt\u00edg\u00fa\u00e0 \u00e0ti B\u00e1r\u00edb\u00fad\u00e0" },
            { "AI", "Or\u00edl\u025b\u0301\u00e8de \u00c0\u00e0ng\u00fal\u00edl\u00e0" },
            { "AL", "Or\u00edl\u025b\u0301\u00e8de \u00c0l\u00f9b\u00e0n\u00ed\u00e1n\u00ec" },
            { "AM", "Or\u00edl\u025b\u0301\u00e8de Am\u00e9n\u00ed\u00e0" },
            { "AO", "Or\u00edl\u025b\u0301\u00e8de \u00c0\u00e0ng\u00f3l\u00e0" },
            { "AR", "Or\u00edl\u025b\u0301\u00e8de Agent\u00edn\u00e0" },
            { "AS", "S\u00e1m\u00f3\u00e1n\u00ec ti Or\u00edl\u025b\u0301\u00e8de \u00c0m\u00e9r\u00edk\u00e0" },
            { "AT", "Or\u00edl\u025b\u0301\u00e8de As\u00edt\u00edr\u00ed\u00e0" },
            { "AU", "Or\u00edl\u025b\u0301\u00e8de \u00c1str\u00e0l\u00ec\u00e1" },
            { "AW", "Or\u00edl\u025b\u0301\u00e8de \u00c1r\u00fab\u00e0" },
            { "AX", "\u00c0w\u0254n Er\u00e9k\u00f9s\u00f9 ti \u00c5land" },
            { "AZ", "Or\u00edl\u025b\u0301\u00e8de As\u025b\u0301b\u00e1j\u00e1n\u00ec" },
            { "BA", "Or\u00edl\u025b\u0301\u00e8de B\u0254\u0300s\u00edn\u00ed\u00e0 \u00e0ti \u0190tis\u025bg\u00f3f\u00edn\u00e0" },
            { "BB", "Or\u00edl\u025b\u0301\u00e8de B\u00e1b\u00e1d\u00f3s\u00ec" },
            { "BD", "Or\u00edl\u025b\u0301\u00e8de B\u00e1ng\u00e1l\u00e1d\u00e9s\u00ec" },
            { "BE", "Or\u00edl\u025b\u0301\u00e8de B\u00e9g\u00ed\u0254\u0301m\u00f9" },
            { "BF", "Or\u00edl\u025b\u0301\u00e8de B\u00f9\u00f9k\u00edn\u00e1 Fas\u00f2" },
            { "BG", "Or\u00edl\u025b\u0301\u00e8de B\u00f9\u00f9g\u00e1r\u00ed\u00e0" },
            { "BH", "Or\u00edl\u025b\u0301\u00e8de B\u00e1r\u00e1n\u00ec" },
            { "BI", "Or\u00edl\u025b\u0301\u00e8de B\u00f9\u00f9r\u00fand\u00ec" },
            { "BJ", "Or\u00edl\u025b\u0301\u00e8de B\u025b\u0300n\u025b\u0300" },
            { "BM", "Or\u00edl\u025b\u0301\u00e8de B\u00e9m\u00fad\u00e0" },
            { "BN", "Or\u00edl\u025b\u0301\u00e8de B\u00far\u00fan\u025b\u0301l\u00ec" },
            { "BO", "Or\u00edl\u025b\u0301\u00e8de B\u0254\u0300l\u00edf\u00edy\u00e0" },
            { "BR", "Oril\u025b\u0300-\u00e8d\u00e8 B\u00e0r\u00e0s\u00edl\u00ec" },
            { "BS", "Or\u00edl\u025b\u0301\u00e8de B\u00e0h\u00e1m\u00e1s\u00ec" },
            { "BT", "Or\u00edl\u025b\u0301\u00e8de B\u00fat\u00e1n\u00ec" },
            { "BW", "Or\u00edl\u025b\u0301\u00e8de B\u0254\u0300t\u00ecs\u00faw\u00e1n\u00e0" },
            { "BY", "Or\u00edl\u025b\u0301\u00e8de B\u00e9l\u00e1r\u00fas\u00ec" },
            { "BZ", "Or\u00edl\u025b\u0301\u00e8de B\u00e8l\u00eds\u025b\u0300" },
            { "CA", "Or\u00edl\u025b\u0301\u00e8de K\u00e1n\u00e1d\u00e0" },
            { "CD", "Oril\u025b\u0301\u00e8de K\u00f3ng\u00f2" },
            { "CF", "Or\u00edl\u025b\u0301\u00e8de \u00c0rin g\u00f9ngun \u00c1f\u00edr\u00edk\u00e0" },
            { "CG", "Or\u00edl\u025b\u0301\u00e8de K\u00f3ng\u00f2" },
            { "CH", "Or\u00edl\u025b\u0301\u00e8de switishilandi" },
            { "CI", "Or\u00edl\u025b\u0301\u00e8de K\u00f3\u00fat\u00e8 for\u00e0" },
            { "CK", "Or\u00edl\u025b\u0301\u00e8de Et\u00edokun K\u00f9\u00fak\u00f9" },
            { "CL", "Or\u00edl\u025b\u0301\u00e8de sh\u00edl\u00e8" },
            { "CM", "Or\u00edl\u025b\u0301\u00e8de Kamer\u00fa\u00fan\u00ec" },
            { "CN", "Oril\u025b\u0300-\u00e8d\u00e8 Sh\u00e1\u00edn\u00e0" },
            { "CO", "Or\u00edl\u025b\u0301\u00e8de K\u00f2l\u00f3m\u00edb\u00eca" },
            { "CR", "Or\u00edl\u025b\u0301\u00e8de Kuusita R\u00edk\u00e0" },
            { "CU", "Or\u00edl\u025b\u0301\u00e8de K\u00fab\u00e0" },
            { "CV", "Or\u00edl\u025b\u0301\u00e8de Et\u00edokun K\u00e1p\u00e9 f\u00e9nd\u00e8" },
            { "CY", "Or\u00edl\u025b\u0301\u00e8de K\u00far\u00fas\u00ec" },
            { "CZ", "Or\u00edl\u025b\u0301\u00e8de sh\u025b\u0301\u025b\u0301k\u00ec" },
            { "DE", "Or\u00edl\u025b\u00e8d\u00e8 J\u00e1m\u00e1n\u00ec" },
            { "DG", "Diego Gashia" },
            { "DJ", "Or\u00edl\u025b\u0301\u00e8de D\u00edb\u0254\u0301\u00f3t\u00ec" },
            { "DK", "Or\u00edl\u025b\u0301\u00e8de D\u025b\u0301m\u00e1k\u00ec" },
            { "DM", "Or\u00edl\u025b\u0301\u00e8de D\u00f2m\u00edn\u00edk\u00e0" },
            { "DO", "Oril\u025b\u0301\u00e8de D\u00f2m\u00edn\u00edk\u00e1n\u00ec" },
            { "DZ", "Or\u00edl\u025b\u0301\u00e8de \u00c0l\u00f9g\u00e8r\u00ed\u00e1n\u00ec" },
            { "EC", "Or\u00edl\u025b\u0301\u00e8de Eku\u00e1d\u00f2" },
            { "EE", "Or\u00edl\u025b\u0301\u00e8de Esitonia" },
            { "EG", "Or\u00edl\u025b\u0301\u00e8de \u00c9g\u00edp\u00edt\u00ec" },
            { "EH", "\u00ccw\u0254\u0300\u00f2\u00f2r\u00f9n S\u00e0h\u00e1r\u00e0" },
            { "ER", "Or\u00edl\u025b\u0301\u00e8de Eritira" },
            { "ES", "Or\u00edl\u025b\u0301\u00e8de Sipani" },
            { "ET", "Or\u00edl\u025b\u0301\u00e8de Etopia" },
            { "EU", "\u00ccsh\u0254\u0300kan Y\u00far\u00f2p\u00f9" },
            { "FI", "Or\u00edl\u025b\u0301\u00e8de Filandi" },
            { "FJ", "Or\u00edl\u025b\u0301\u00e8de Fiji" },
            { "FK", "Or\u00edl\u025b\u0301\u00e8de Etikun Fakalandi" },
            { "FM", "Or\u00edl\u025b\u0301\u00e8de Makoronesia" },
            { "FO", "\u00c0w\u0254n Er\u00e9k\u00f9s\u00f9 ti Faroe" },
            { "FR", "Or\u00edl\u025b\u0301\u00e8de Faranse" },
            { "GA", "Or\u00edl\u025b\u0301\u00e8de Gabon" },
            { "GB", "Or\u00edl\u025b\u0301\u00e8d\u00e8 G\u025b\u0300\u025b\u0301s\u00ec" },
            { "GD", "Or\u00edl\u025b\u0301\u00e8de Genada" },
            { "GE", "Or\u00edl\u025b\u0301\u00e8de G\u0254gia" },
            { "GF", "Or\u00edl\u025b\u0301\u00e8de Firenshi Guana" },
            { "GH", "Or\u00edl\u025b\u0301\u00e8de Gana" },
            { "GI", "Or\u00edl\u025b\u0301\u00e8de Gibaratara" },
            { "GL", "Or\u00edl\u025b\u0301\u00e8de Gerelandi" },
            { "GM", "Or\u00edl\u025b\u0301\u00e8de Gambia" },
            { "GN", "Or\u00edl\u025b\u0301\u00e8de Gene" },
            { "GP", "Or\u00edl\u025b\u0301\u00e8de Gadelope" },
            { "GQ", "Or\u00edl\u025b\u0301\u00e8de Ekutoria Gini" },
            { "GR", "Or\u00edl\u025b\u0301\u00e8de Geriisi" },
            { "GS", "G\u00fa\u00fas\u00f9 Georgia \u00e0ti G\u00fa\u00fas\u00f9 \u00c0w\u0254n Er\u00e9k\u00f9s\u00f9 Sandwich" },
            { "GT", "Or\u00edl\u025b\u0301\u00e8de Guatemala" },
            { "GU", "Or\u00edl\u025b\u0301\u00e8de Guamu" },
            { "GW", "Or\u00edl\u025b\u0301\u00e8de Gene-Busau" },
            { "GY", "Or\u00edl\u025b\u0301\u00e8de Guyana" },
            { "HK", "Hong Kong SAR ti Sh\u00e1\u00ecn\u00e0" },
            { "HN", "Or\u00edl\u025b\u0301\u00e8de Hondurasi" },
            { "HR", "Or\u00edl\u025b\u0301\u00e8de K\u00f2r\u00f3\u00e1t\u00ed\u00e0" },
            { "HT", "Or\u00edl\u025b\u0301\u00e8de Haati" },
            { "HU", "Or\u00edl\u025b\u0301\u00e8de Hungari" },
            { "IC", "\u0190r\u00e9k\u00f9s\u00f9 K\u00e1n\u00e1r\u00ec" },
            { "ID", "Or\u00edl\u025b\u0301\u00e8de Indonesia" },
            { "IE", "Or\u00edl\u025b\u0301\u00e8de Ailandi" },
            { "IL", "Or\u00edl\u025b\u0301\u00e8de Iser\u025bli" },
            { "IN", "Or\u00edl\u025b\u0301\u00e8de India" },
            { "IO", "Or\u00edl\u025b\u0301\u00e8de Et\u00edkun \u00cdnd\u00ed\u00e1n\u00ec ti \u00ccl\u00fa B\u00edr\u00edt\u00eds\u00ec" },
            { "IQ", "Or\u00edl\u025b\u0301\u00e8de Iraki" },
            { "IR", "Or\u00edl\u025b\u0301\u00e8de Irani" },
            { "IS", "Or\u00edl\u025b\u0301\u00e8de Ashilandi" },
            { "IT", "Or\u00edl\u025b\u0301\u00e8de It\u00e1li" },
            { "JM", "Or\u00edl\u025b\u0301\u00e8de Jamaika" },
            { "JO", "Or\u00edl\u025b\u0301\u00e8de J\u0254dani" },
            { "JP", "Or\u00edl\u025b\u0301\u00e8de Japani" },
            { "KE", "Or\u00edl\u025b\u0301\u00e8de Kenya" },
            { "KG", "Or\u00edl\u025b\u0301\u00e8de Kurishisitani" },
            { "KH", "Or\u00edl\u025b\u0301\u00e8de K\u00e0m\u00f9b\u00f3d\u00ed\u00e0" },
            { "KI", "Or\u00edl\u025b\u0301\u00e8de Kiribati" },
            { "KM", "Or\u00edl\u025b\u0301\u00e8de K\u00f2m\u00f2r\u00f3s\u00ec" },
            { "KN", "Or\u00edl\u025b\u0301\u00e8de Kiiti ati Neefi" },
            { "KP", "Or\u00edl\u025b\u0301\u00e8de Guusu K\u0254ria" },
            { "KR", "Or\u00edl\u025b\u0301\u00e8de Ariwa K\u0254ria" },
            { "KW", "Or\u00edl\u025b\u0301\u00e8de Kuweti" },
            { "KY", "Or\u00edl\u025b\u0301\u00e8de Et\u00edokun K\u00e1m\u00e1n\u00ec" },
            { "KZ", "Or\u00edl\u025b\u0301\u00e8de Kashashatani" },
            { "LA", "Or\u00edl\u025b\u0301\u00e8de Laosi" },
            { "LB", "Or\u00edl\u025b\u0301\u00e8de Lebanoni" },
            { "LC", "Or\u00edl\u025b\u0301\u00e8de Lushia" },
            { "LI", "Or\u00edl\u025b\u0301\u00e8de L\u025bshit\u025bnisiteni" },
            { "LK", "Or\u00edl\u025b\u0301\u00e8de Siri Lanka" },
            { "LR", "Or\u00edl\u025b\u0301\u00e8de Laberia" },
            { "LS", "Or\u00edl\u025b\u0301\u00e8de Lesoto" },
            { "LT", "Or\u00edl\u025b\u0301\u00e8de Lituania" },
            { "LU", "Or\u00edl\u025b\u0301\u00e8de Lusemogi" },
            { "LV", "Or\u00edl\u025b\u0301\u00e8de Latifia" },
            { "LY", "Or\u00edl\u025b\u0301\u00e8de Libiya" },
            { "MA", "Or\u00edl\u025b\u0301\u00e8de Moroko" },
            { "MC", "Or\u00edl\u025b\u0301\u00e8de Monako" },
            { "MD", "Or\u00edl\u025b\u0301\u00e8de Modofia" },
            { "MG", "Or\u00edl\u025b\u0301\u00e8de Madasika" },
            { "MH", "Or\u00edl\u025b\u0301\u00e8de Etikun M\u00e1shali" },
            { "ML", "Or\u00edl\u025b\u0301\u00e8de Mali" },
            { "MM", "Or\u00edl\u025b\u0301\u00e8de Manamari" },
            { "MN", "Or\u00edl\u025b\u0301\u00e8de Mogolia" },
            { "MO", "Macao SAR ti Sh\u00e1\u00ecn\u00e0" },
            { "MP", "Or\u00edl\u025b\u0301\u00e8de Etikun Guusu Mariana" },
            { "MQ", "Or\u00edl\u025b\u0301\u00e8de Matinikuwi" },
            { "MR", "Or\u00edl\u025b\u0301\u00e8de Maritania" },
            { "MS", "Or\u00edl\u025b\u0301\u00e8de Motserati" },
            { "MT", "Or\u00edl\u025b\u0301\u00e8de Malata" },
            { "MU", "Or\u00edl\u025b\u0301\u00e8de Maritiusi" },
            { "MV", "Or\u00edl\u025b\u0301\u00e8de Maladifi" },
            { "MW", "Or\u00edl\u025b\u0301\u00e8de Malawi" },
            { "MX", "Or\u00edl\u025b\u0301\u00e8de Mesiko" },
            { "MY", "Or\u00edl\u025b\u0301\u00e8de Malasia" },
            { "MZ", "Or\u00edl\u025b\u0301\u00e8de Moshamibiku" },
            { "NA", "Or\u00edl\u025b\u0301\u00e8de Namibia" },
            { "NC", "Or\u00edl\u025b\u0301\u00e8de Kaledonia Titun" },
            { "NE", "Or\u00edl\u025b\u0301\u00e8de N\u00e0\u00ecj\u00e1" },
            { "NF", "Or\u00edl\u025b\u0301\u00e8de Etikun N\u0254\u0301\u00faf\u00f3k\u00ec" },
            { "NG", "Oril\u025b\u0300-\u00e8d\u00e8 N\u00e0\u00ecj\u00edr\u00ed\u00e0" },
            { "NI", "Or\u00edl\u025b\u0301\u00e8de NIkaragua" },
            { "NL", "Or\u00edl\u025b\u0301\u00e8de Nedalandi" },
            { "NO", "Or\u00edl\u025b\u0301\u00e8de N\u0254\u0254wii" },
            { "NP", "Or\u00edl\u025b\u0301\u00e8de Nepa" },
            { "NR", "Or\u00edl\u025b\u0301\u00e8de Nauru" },
            { "NU", "Or\u00edl\u025b\u0301\u00e8de Niue" },
            { "NZ", "Or\u00edl\u025b\u0301\u00e8de shilandi Titun" },
            { "OM", "Or\u00edl\u025b\u0301\u00e8de \u0186\u0254ma" },
            { "PA", "Or\u00edl\u025b\u0301\u00e8de Panama" },
            { "PE", "Or\u00edl\u025b\u0301\u00e8de Peru" },
            { "PF", "Or\u00edl\u025b\u0301\u00e8de Firenshi Polinesia" },
            { "PG", "Or\u00edl\u025b\u0301\u00e8de Paapu ti Giini" },
            { "PH", "Or\u00edl\u025b\u0301\u00e8de filipini" },
            { "PK", "Or\u00edl\u025b\u0301\u00e8de Pakisitan" },
            { "PL", "Or\u00edl\u025b\u0301\u00e8de Polandi" },
            { "PM", "Or\u00edl\u025b\u0301\u00e8de P\u025b\u025bri ati mikuloni" },
            { "PN", "Or\u00edl\u025b\u0301\u00e8de Pikarini" },
            { "PR", "Or\u00edl\u025b\u0301\u00e8de P\u0254to Riko" },
            { "PS", "Agb\u00e8gb\u00e8 Pal\u025bs\u00edt\u00ed\u00e0n\u00f9" },
            { "PT", "Or\u00edl\u025b\u0301\u00e8de P\u0254\u0301t\u00fag\u00e0" },
            { "PW", "Or\u00edl\u025b\u0301\u00e8de Paalu" },
            { "PY", "Or\u00edl\u025b\u0301\u00e8de Paraguye" },
            { "QA", "Or\u00edl\u025b\u0301\u00e8de Kota" },
            { "RE", "Or\u00edl\u025b\u0301\u00e8de Riuniyan" },
            { "RO", "Or\u00edl\u025b\u0301\u00e8de Romaniya" },
            { "RU", "Or\u00edl\u025b\u0301\u00e8de R\u0254shia" },
            { "RW", "Or\u00edl\u025b\u0301\u00e8de Ruwanda" },
            { "SA", "Or\u00edl\u025b\u0301\u00e8de Saudi Arabia" },
            { "SB", "Or\u00edl\u025b\u0301\u00e8de Etikun Solomoni" },
            { "SC", "Or\u00edl\u025b\u0301\u00e8de sesh\u025bl\u025bsi" },
            { "SD", "Or\u00edl\u025b\u0301\u00e8de Sudani" },
            { "SE", "Or\u00edl\u025b\u0301\u00e8de Swidini" },
            { "SG", "Or\u00edl\u025b\u0301\u00e8de Singapo" },
            { "SH", "Or\u00edl\u025b\u0301\u00e8de H\u025blena" },
            { "SI", "Or\u00edl\u025b\u0301\u00e8de Silofania" },
            { "SK", "Or\u00edl\u025b\u0301\u00e8de Silofakia" },
            { "SL", "Or\u00edl\u025b\u0301\u00e8de Siria looni" },
            { "SM", "Or\u00edl\u025b\u0301\u00e8de Sani Marino" },
            { "SN", "Or\u00edl\u025b\u0301\u00e8de S\u025bn\u025bga" },
            { "SO", "Or\u00edl\u025b\u0301\u00e8de Somalia" },
            { "SR", "Or\u00edl\u025b\u0301\u00e8de Surinami" },
            { "ST", "Or\u00edl\u025b\u0301\u00e8de Sao tomi ati piriishipi" },
            { "SV", "Or\u00edl\u025b\u0301\u00e8de \u0190\u025bs\u00e1f\u00e1d\u00f2" },
            { "SY", "Or\u00edl\u025b\u0301\u00e8de Siria" },
            { "SZ", "Or\u00edl\u025b\u0301\u00e8de Sashiland" },
            { "TC", "Or\u00edl\u025b\u0301\u00e8de T\u0254\u0254ki ati Etikun Kak\u0254si" },
            { "TD", "Or\u00edl\u025b\u0301\u00e8de sh\u00e0\u00e0d\u00ec" },
            { "TF", "Agb\u00e8gb\u00e8 G\u00fa\u00fas\u00f9 Faransh\u00e9" },
            { "TG", "Or\u00edl\u025b\u0301\u00e8de Togo" },
            { "TH", "Or\u00edl\u025b\u0301\u00e8de Tailandi" },
            { "TJ", "Or\u00edl\u025b\u0301\u00e8de Takisitani" },
            { "TK", "Or\u00edl\u025b\u0301\u00e8de Tokelau" },
            { "TL", "Or\u00edl\u025b\u0301\u00e8de \u00ccl\u00e0O\u00f2r\u00f9n T\u00edm\u0254\u0300" },
            { "TM", "Or\u00edl\u025b\u0301\u00e8de T\u0254\u0254kimenisita" },
            { "TN", "Or\u00edl\u025b\u0301\u00e8de Tunishia" },
            { "TO", "Or\u00edl\u025b\u0301\u00e8de Tonga" },
            { "TR", "Or\u00edl\u025b\u0301\u00e8de T\u0254\u0254ki" },
            { "TT", "Or\u00edl\u025b\u0301\u00e8de Tirinida ati Tobaga" },
            { "TV", "Or\u00edl\u025b\u0301\u00e8de Tufalu" },
            { "TW", "Or\u00edl\u025b\u0301\u00e8de Taiwani" },
            { "TZ", "Or\u00edl\u025b\u0301\u00e8de T\u00e0\u01f9s\u00e1n\u00ed\u00e0" },
            { "UA", "Or\u00edl\u025b\u0301\u00e8de Ukarini" },
            { "UG", "Or\u00edl\u025b\u0301\u00e8de Uganda" },
            { "UM", "\u00c0w\u0254n Er\u00e9k\u00f9s\u00f9 K\u00e9k\u00e8k\u00e9 Agb\u00e8gb\u00e8 US" },
            { "UN", "\u00ccsh\u0254\u0300kan \u00e0gb\u00e1y\u00e9" },
            { "US", "Or\u00edl\u025b\u0300-\u00e8d\u00e8 Am\u025brik\u00e0" },
            { "UY", "Or\u00edl\u025b\u0301\u00e8de Nruguayi" },
            { "UZ", "Or\u00edl\u025b\u0301\u00e8de Nshib\u025bkisitani" },
            { "VC", "Or\u00edl\u025b\u0301\u00e8de Fis\u025bnnti ati Genadina" },
            { "VE", "Or\u00edl\u025b\u0301\u00e8de F\u025bn\u025bshu\u025bla" },
            { "VG", "Or\u00edl\u025b\u0301\u00e8de Et\u00edkun F\u00e1g\u00edn\u00ec ti \u00ecl\u00fa B\u00edr\u00edt\u00eds\u00ec" },
            { "VI", "Or\u00edl\u025b\u0301\u00e8de Etikun Fagini ti Am\u025brika" },
            { "VN", "Or\u00edl\u025b\u0301\u00e8de F\u025btinami" },
            { "VU", "Or\u00edl\u025b\u0301\u00e8de Faniatu" },
            { "WF", "Or\u00edl\u025b\u0301\u00e8de Wali ati futuna" },
            { "WS", "Or\u00edl\u025b\u0301\u00e8de Sam\u0254" },
            { "YE", "Or\u00edl\u025b\u0301\u00e8de yemeni" },
            { "YT", "Or\u00edl\u025b\u0301\u00e8de Mayote" },
            { "ZA", "G\u00fa\u00fash\u00f9 \u00c1f\u00edr\u00edk\u00e0" },
            { "ZM", "Or\u00edl\u025b\u0301\u00e8de shamibia" },
            { "ZW", "Or\u00edl\u025b\u0301\u00e8de shimibabe" },
            { "ZZ", "\u00c0gb\u00e8gb\u00e8 \u00e0\u00ecm\u0254\u0300" },
            { "cu", "S\u00edl\u00e1f\u00ed\u00edk\u00ec Il\u00e9 \u00ccj\u0254\u0301s\u00ecn" },
            { "da", "\u00c8d\u00e8 Il\u025b\u0300 Denmark" },
            { "en", "\u00c8d\u00e8 G\u025b\u0300\u025b\u0301s\u00ec" },
            { "es", "\u00c8d\u00e8 S\u00edp\u00e1n\u00ed\u00ecsh\u00ec" },
            { "id", "\u00c8d\u00e8 Indon\u00e9sh\u00ed\u00e0" },
            { "ii", "Sh\u00edku\u00e1n Y\u00ec" },
            { "kk", "Kashak\u00ec" },
            { "ks", "Kash\u00edmir\u00ec" },
            { "ku", "K\u0254dish\u00ec" },
            { "kw", "K\u0254\u0301n\u00ec\u00ecsh\u00ec" },
            { "lb", "L\u00f9sh\u025b\u0301mb\u0254\u0301\u0254\u0300g\u00ec" },
            { "nb", "N\u0254\u0301\u0254\u0301w\u00e8 Bok\u00edm\u00e0l" },
            { "nl", "\u00c8d\u00e8 D\u0254\u0301\u0254\u0300sh\u00ec" },
            { "nn", "N\u0254\u0301\u0254\u0301w\u00e8 N\u00edn\u0254\u0300s\u00eck\u00ec" },
            { "om", "\u00d2r\u00f2m\u0254\u0301" },
            { "os", "\u0186sh\u025b\u0301t\u00ed\u00eck\u00ec" },
            { "pt", "\u00c8d\u00e8 P\u0254tog\u00ed" },
            { "qu", "K\u00fa\u025b\u0301\u0144j\u00f9\u00e0" },
            { "rm", "R\u00f3m\u00e1\u01f9sh\u00ec" },
            { "ru", "\u00c8d\u00e8 R\u0254\u0301sh\u00ed\u00e0" },
            { "sn", "Sh\u0254n\u00e0" },
            { "tr", "\u00c8d\u00e8 T\u0254\u0254kisi" },
            { "ug", "Y\u00fag\u0254\u0300" },
            { "vo", "F\u0254\u0301l\u00e1p\u00f9\u00f9k\u00f9" },
            { "wo", "W\u0254\u0301l\u0254\u0301\u0254\u0300f\u00f9" },
            { "zh", "\u00c8d\u00e8 Mandarin t\u00ed w\u0254\u0301n \u0144 s\u0254 l\u00f3r\u00edl\u025b\u0300-\u00e8d\u00e8 Sh\u00e1\u00edn\u00e0" },
            { "zu", "\u00c8d\u00e8 Shulu" },
            { "agq", "\u00c1g\u025b\u0300\u025b\u0300m\u00f9" },
            { "bez", "B\u025b\u0301n\u00e0" },
            { "chr", "Sh\u025b\u0301r\u00f3ki\u00ec" },
            { "dje", "Sh\u00e1r\u00fam\u00e0" },
            { "dsb", "Shob\u00ed\u00e0n\u00f9 \u00ccp\u00ecl\u025b\u0300" },
            { "ebu", "\u0190mb\u00f9" },
            { "jmc", "M\u00e1sh\u00e1m\u00e8" },
            { "khq", "Koira Sh\u00ed\u00edn\u00ec" },
            { "kln", "K\u00e1l\u025bnj\u00edn" },
            { "ksb", "Sh\u00e1\u0144b\u00e1l\u00e0" },
            { "mul", "\u0186l\u0254\u0301p\u0254\u0300 \u00e8d\u00e8" },
            { "nds", "J\u00e1m\u00e1n\u00ec \u00ecp\u00ecl\u025b\u0300" },
            { "nmg", "K\u00edw\u00e1sh\u00ed\u00f2" },
            { "nus", "N\u00fa\u025b\u0300" },
            { "nyn", "\u0143y\u00e1k\u0254\u0301l\u00e8" },
            { "prg", "P\u00far\u00fash\u00ed\u00e0n\u00f9" },
            { "seh", "Sh\u025bn\u00e0" },
            { "shi", "Tashel\u00ed\u00ect\u00ec" },
            { "teo", "T\u025b\u0301s\u00f2" },
            { "und", "\u00c8d\u00e8 \u00e0\u00ecm\u0254\u0300" },
            { "wae", "W\u0254s\u00e0" },
            { "xog", "Sh\u00f3g\u00e0" },
            { "yav", "Yangb\u025bn" },
            { "zgh", "\u00c0f\u025bn\u00f9k\u00f2 T\u00e1m\u00e1s\u00e1\u00ect\u00ec ti M\u00f2r\u00f3k\u00f2" },
            { "Armn", "\u00c0m\u025b\u0301n\u00ed\u00e0" },
            { "Cyrl", "\u00e8d\u00e8 il\u025b\u0300 R\u0254\u0301sh\u00ed\u00e0" },
            { "Deva", "D\u025bfanag\u00e1r\u00ec" },
            { "Ethi", "\u0190ti\u00f3p\u00ed\u00eck\u00ec" },
            { "Geor", "J\u0254\u0301j\u00ed\u00e0n\u00f9" },
            { "Grek", "J\u0254\u0301j\u00ed\u00e0" },
            { "Hanb", "Han p\u025b\u0300l\u00fa Bopom\u00f3f\u00f2" },
            { "Hans", "t\u00ed w\u0254\u0301n m\u00fa r\u0254r\u00f9n." },
            { "Hant", "Hans \u00e0t\u0254w\u0254\u0301d\u0254\u0301w\u0254\u0301" },
            { "Hrkt", "\u00ecl\u00e0n\u00e0 \u00e0f\u0254w\u0254\u0301k\u0254 ar\u00e1 J\u00e0p\u00e1n\u00f9" },
            { "Khmr", "K\u025bm\u025b\u0300" },
            { "Zmth", "\u00c0m\u00ec \u00ccsh\u00e8s\u00ecr\u00f2" },
            { "Zsym", "\u00c0w\u0254n \u00e0m\u00ec" },
            { "Zxxx", "Aik\u0254sil\u025b" },
            { "Zyyy", "W\u0254\u0301p\u0254\u0300" },
            { "Zzzz", "\u00ccsh\u0254w\u0254\u0301k\u0254\u0300w\u00e9 \u00e0\u00ecm\u0254\u0300" },
            { "de_AT", "\u00c8d\u00e8 J\u00e1m\u00e1n\u00ec (\u0186\u0301s\u00edr\u00ed\u00e0 )" },
            { "de_CH", "\u00c8d\u00e8 Il\u025b\u0300 J\u00e1m\u00e1n\u00ec (Or\u00edl\u025b\u0301\u00e8de sw\u00edts\u00e0land\u00ec)" },
            { "en_AU", "\u00c8d\u00e8 G\u025b\u0300\u025b\u0301s\u00ec (\u00f3r\u00edl\u025b\u0300-\u00e8d\u00e8 \u0186sir\u00e9l\u00ed\u00e0)" },
            { "en_CA", "\u00c8d\u00e8 G\u025b\u0300\u025b\u0301s\u00ec (Or\u00edl\u025b\u0300-\u00e8d\u00e8 K\u00e1n\u00e1d\u00e0)" },
            { "en_GB", "\u00c8d\u00e8 \u00f2y\u00ecnb\u00f3 G\u025b\u0300\u025b\u0301s\u00ec" },
            { "es_ES", "\u00c8d\u00e8 S\u00edp\u00e1n\u00ed\u00ecsh\u00ec (or\u00edl\u025b\u0300-\u00e8d\u00e8 Y\u00far\u00f3\u00f2p\u00f9)" },
            { "es_MX", "\u00c8d\u00e8 S\u00edp\u00e1n\u00ed\u00ecsh\u00ec (or\u00edl\u025b\u0300-\u00e8d\u00e8 M\u025b\u0301s\u00edk\u00f2)" },
            { "fr_CA", "\u00c8d\u00e8 Farans\u00e9 (or\u00edl\u025b\u0300-\u00e8d\u00e8 K\u00e1n\u00e1d\u00e0)" },
            { "fr_CH", "\u00c8d\u00e8 Faransh\u00e9 (S\u00faw\u00eds\u00e0la\u01f9d\u00ec)" },
            { "pt_BR", "\u00c8d\u00e8 P\u0254tog\u00ed (Oril\u025b\u0300-\u00e8d\u00e8 Br\u00e0s\u00edl)" },
            { "pt_PT", "\u00c8d\u00e8 P\u0254tog\u00ed (or\u00edl\u025b\u0300-\u00e8d\u00e8 Y\u00far\u00f3\u00f2p\u00f9)" },
            { "es_419", "\u00c8d\u00e8 S\u00edp\u00e1n\u00ed\u00ecsh\u00ec (or\u00edl\u025b\u0300-\u00e8d\u00e8 L\u00e1t\u00ecn-Am\u025b\u0301r\u00edk\u00e0) ( \u00c8d\u00e8 S\u00edp\u00e1n\u00ed\u00ecsh\u00ec (L\u00e1t\u00ecn-Am\u025b\u0301r\u00edk\u00e0)" },
            { "key.ca", "K\u00e0l\u025b\u0301\u0144d\u00e0" },
            { "key.cf", "\u00ccg\u00fanr\u00e9g\u00e9 K\u0254\u0301r\u025b\u0301\u0144s\u00ec" },
            { "key.co", "\u00c8t\u00f2 \u0190l\u025b\u0301s\u025b\u025bs\u025b" },
            { "key.cu", "K\u0254\u0301r\u025b\u0301\u0144s\u00ec" },
            { "key.ms", "\u00c8to \u00ccdiw\u0254\u0300n" },
            { "key.nu", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0" },
            { "zh_Hant", "\u00c8d\u00e8 \u00ccb\u00edl\u025b\u0300 Sh\u00e1\u00edn\u00e0" },
            { "type.ca.roc", "K\u00e0l\u025b\u0300\u0144d\u00e0 Minguo" },
            { "type.nu.arab", "\u00e0w\u0254n d\u00edj\u00edt\u00ec L\u00e0rub\u00e1w\u00e1-\u00cdnd\u00ed\u00e0" },
            { "type.nu.armn", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 \u00c0m\u025b\u0301n\u00ed\u00e0" },
            { "type.nu.beng", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec B\u00e1\u0144g\u00edl\u00e0" },
            { "type.nu.deva", "\u00c0w\u0254n d\u00edj\u00ec\u00ect\u00ec Defanag\u00e1r\u00ec" },
            { "type.nu.ethi", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 \u0190ti\u00f3p\u00ed\u00eck\u00ec" },
            { "type.nu.geor", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 J\u0254\u0301j\u00ed\u00e0" },
            { "type.nu.grek", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 G\u00edr\u00ed\u00eck\u00ec" },
            { "type.nu.gujr", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec G\u00f9j\u00e1r\u00e1t\u00ec" },
            { "type.nu.guru", "\u00c0w\u0254n D\u00edj\u00ed\u00ect\u00ec Gurumuk\u00ec" },
            { "type.nu.hans", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 \u00ccr\u0254\u0300r\u00f9n ti Sh\u00e1\u00ecn\u00e0" },
            { "type.nu.hant", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 \u00ccb\u00edl\u025b\u0300 Sh\u00e1\u00ecn\u00e0" },
            { "type.nu.hebr", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 H\u00e9b\u00e9r\u00f9" },
            { "type.nu.jpan", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 J\u00e1p\u00e0n\u00f9" },
            { "type.nu.khmr", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec K\u025b\u0301m\u025b\u0300" },
            { "type.nu.knda", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec kanada" },
            { "type.nu.laoo", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec L\u00e1\u00f3" },
            { "type.nu.latn", "D\u00edj\u00ed\u00edt\u00ec \u00ccw\u0254\u0300 O\u00f2r\u00f9n" },
            { "type.nu.mlym", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec M\u00e1l\u00e0y\u00e1l\u00e1m\u00f9" },
            { "type.nu.mymr", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec My\u00e1nmar\u00ed" },
            { "type.nu.orya", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec \u00d2d\u00ed\u00e0" },
            { "type.nu.taml", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec \u00ccb\u00edl\u025b\u0300 T\u00e1m\u00edl\u00f9" },
            { "type.nu.telu", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec T\u00e9l\u00fag\u00f9" },
            { "type.nu.thai", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec Thai" },
            { "type.nu.tibt", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec Tibet\u00e1n" },
            { "type.ca.dangi", "K\u00e0l\u025b\u0300\u0144d\u00e0 dangi" },
            { "type.co.ducet", "\u00c8t\u00f2 \u0190l\u025b\u0301s\u025b\u025bs\u025b \u00c0k\u00f9\u00e0y\u00e0n Unicode" },
            { "type.nu.roman", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec R\u00f3m\u00e1n\u00f9" },
            { "type.ca.hebrew", "K\u00e0l\u025b\u0300\u0144d\u00e0 H\u00e9b\u00e9r\u00f9" },
            { "type.co.search", "\u00ccsh\u00e0w\u00e1r\u00ed \u00c8te-Gbogbogb\u00f2" },
            { "type.ms.metric", "\u00c8to M\u025b\u0301t\u00edr\u00ed\u00eck\u00ec" },
            { "type.ca.chinese", "K\u00e0l\u025b\u0300\u0144d\u00e0 ti Sh\u00e1\u00ecn\u00e0" },
            { "type.ca.islamic", "K\u00e0l\u025b\u0300\u0144d\u00e0 L\u00e1r\u00fab\u00e1w\u00e1" },
            { "type.ca.iso8601", "K\u00e0l\u025b\u0301\u0144d\u00e0 ISO-8601" },
            { "type.ca.persian", "K\u00e0l\u025b\u0300\u0144d\u00e0 P\u00e1s\u00ed\u00e0n\u00f9" },
            { "type.cf.account", "\u00ccg\u00fanr\u00e9g\u00e9 \u00ccshir\u00f2 Ow\u00f3 K\u0254\u0301r\u025b\u0301\u0144s\u00ec" },
            { "type.nu.arabext", "\u00c0w\u0254n D\u00edj\u00ed\u00ect\u00ec L\u00e1r\u00fab\u00e1w\u00e1-\u00cdnd\u00ed\u00e0 f\u00edf\u025b\u0300" },
            { "type.nu.armnlow", "\u00c0w\u0254n N\u0254\u0301\u0144b\u00e0 K\u00e9k\u00e8k\u00e9 ti Am\u025b\u0301r\u00edk\u00e0" },
            { "type.nu.greklow", "\u00c0w\u0254n N\u0254\u0301\u0144b\u00e0 G\u00edr\u00ed\u00eck\u00ec K\u00e9k\u00e8k\u00e9" },
            { "type.nu.hanidec", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 D\u025b\u0301s\u00edm\u00e0 Sh\u00e1\u00ecn\u00e0" },
            { "type.nu.hansfin", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 \u00ccsh\u00fan\u00e1 \u00ccr\u0254\u0300r\u00f9n Sh\u00e1\u00ecn\u00e0" },
            { "type.nu.hantfin", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 \u00ccsh\u00fan\u00e1 \u00ccb\u00edl\u025b\u0300 Sh\u00e1\u00ecn\u00e0" },
            { "type.nu.jpanfin", "\u00c0w\u0254n n\u0254\u0301\u0144b\u00e0 \u00ccsh\u00fan\u00e1 J\u00e0p\u00e1\u00e0n\u00f9" },
            { "type.nu.tamldec", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec T\u00e0m\u00edl\u00f9" },
            { "type.ca.buddhist", "K\u00e0l\u025b\u0300\u0144d\u00e0 Buddhist" },
            { "type.ca.ethiopic", "K\u00e0l\u025b\u0300\u0144d\u00e0 \u0190t\u00ed\u00f3p\u00ed\u00eck\u00ec" },
            { "type.ca.japanese", "K\u00e0l\u025b\u0300\u0144d\u00e0 ti J\u00e0p\u00e1n\u00f9" },
            { "type.cf.standard", "\u00ccg\u00fanr\u00e9g\u00e9 Gb\u00e8d\u00e9ke K\u0254\u0301r\u025b\u0301\u0144s\u00ec" },
            { "type.ms.uksystem", "\u00c8to \u00ccdiw\u0254\u0300n \u0186ba" },
            { "type.ms.ussystem", "\u00c8to \u00ccdiw\u0254\u0300n US" },
            { "type.nu.fullwide", "\u00c0w\u0254n D\u00edj\u00ed\u00ect\u00ec F\u00edf\u025b\u0300-\u0190\u0300k\u00fan" },
            { "type.nu.romanlow", "\u00c0w\u0254n d\u00edj\u00ed\u00ect\u00ec R\u00f3m\u00e1n\u00f9 K\u00e9ker\u00e9" },
            { "type.ca.gregorian", "K\u00e0l\u025b\u0301\u0144d\u00e0 Gregory" },
        };
        return data;
    }
}
